==> nextcloud-29.0.12.tgz: nextcloud/apps/circles/l10n/ka_GE.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "თქვენ წაშალეთ {circle}",
    "{author} deleted {circle}" : "{author} მომხმარებელმა წაშალა {circle}",
    "You removed {member} from {circle}" : "თქვენ ამოშალეთ {member} {circle} წრიდან",
    "You joined {circle}" : "თქვენ შეუერთიდ წრეს {circle}",
    "{member} joined {circle}" : "{member} შეუერთდა წრეს {circle}",
    "You accepted the invitation to join {circle}" : "თქვენ მიიღეთ მოწვევა შეუერთდეთ {circle} წრეს",
    "{member} accepted the invitation to join {circle}" : "{member} მომხმარებელმა მიიღო მოწვევა შეუერთდეს {circle} წრეს",
    "You added {member} as member to {circle}" : "თქვენ მომხმარებელი {member} გააწევრიანეთ წრეში {circle}",
    "You have been added as member to {circle} by {author}" : "თქვენ {author} მომხმარებელმა გაგაწევრიანათ წრეში {circle}",
    "{member} has been added as member to {circle} by {author}" : "{member} წრეში {circle} გაწევრიანდა {author} მომხმარებლის მიერ",
    "You added {external} to {circle}" : "თქვენ დაამატეთ {external} წრეში {circle}",
    "{external} has been added to {circle} by {author}" : "{external} წრეში {circle} დაამატა მომხმარებელმა {author}",
    "You accepted {member}'s request to join {circle}" : "თქვენ მიიღეთ {member} წევრის მოთხოვნა {circle} წრეში გასაწევრიანებლად",
    "Your request to join {circle} has been accepted by {author}" : "თქვენი მოთხოვნა წრეში {circle} გაწევრიანებაზე მიიღო მომხმარებელმა {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} მომხმარებლისა მოთხოვნა გაწევრიანდეს {circle} წრეში მიღებულ იქნა {author} მომხმარებლის მიერ",
    "You left {circle}" : "თქვენ დატოვეთ {circle}",
    "{member} left {circle}" : "{member} მომხმარებელმა დატოვა {circle}",
    "You declined the invitation to join {circle}" : "თქვენ უარყავით მოწვევა გაწევრიანდეთ {circle} წრეში",
    "{member} declined an invitation to join {circle}" : "{member} მომხმარებელმა უარყო მოწვევა გაწევრიანდეს {circle} წრეში",
    "You cancelled your request to join {circle}" : "თქვენ გააუქმეთ მოთხოვნა გაწევრიანდეთ {circle} წრეში",
    "You have been removed from {circle} by {author}" : "თქვენ {author} მომხმარებელმა {circle} წრიდან ამოგშალათ",
    "{member} has been removed from {circle} by {author}" : "{member} მომხმარებელი {circle} წრიდან {author} მომხმარებელმა ამოშალა",
    "You removed {external} from {circle}" : "თქვენ {external} ამოშალეთ {circle} წრიდან",
    "{external} has been removed from {circle} by {author}" : "{author} მომხმარებელმა ამოშალა {external} წრიდან {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "თქვენ უარყავით {member} მომხმარებლის მოწვევა შეუერთდეთ {circle} წრეს",
    "Your invitation to join {circle} has been cancelled by {author}" : "მოწვევა რომ შეუერთდეთ {circle} უაყოფილ იქნა {author} მომხმარებლის მიერ",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} მომხმარებელმა უარყო {member} მომხმარებლის მოწვევა შეუერთდეს {circle} წრეს",
    "You dismissed {member}'s request to join {circle}" : "თქვენ უარყავით {member} მომხმარებლის მოთხოვნა {circle} წრეში გასაწევრიანებლად",
    "Your request to join {circle} has been dismissed by {author}" : "თქვენი მოთხოვნა შეუერთდეთ {circle} წრეს {author} მომხმარებლის მიერ უარყოფილ იქნა",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} მომხმარებლის მოთხოვნა შეუერთდეს {circle} წრეს უარყო {author} მომხმარებელმა",
    "You invited {member} to join {circle}" : "თქვენ მოიწვიეთ {member} შეუერთდეს {circle} წრეს",
    "You have been invited to join {circle} by {author}" : "თქვენ {author} მომხმარებელმა მოგიწვიათ შეუერთდეთ {circle} წრეს",
    "{member} has been invited to join {circle} by {author}" : "{author} მომხმარებელმა მოიწვია {member} მომხამრებელი შეუერთდეს {circle} წრეს",
    "You changed {member}'s level in {circle} to %1$s" : "თქვენ {member} მომხმარებლის დონე {circle} წრეში შეცვალეთ მნიშვნელობაზე %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} მომხმარებელმა თქვენი დონე {circle} წრეში შეცვალა მნიშვნელობაზე %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} მომხმარებელმა {member} მომხმარებლის დონე {circle} წრეში შეცვალა მნიშვნელობაზე %1$s",
    "You sent a request to join {circle}" : "თქვენ გაგზვნეთ მოთხოვნა გაწევრიანდეთ {circle} წრეში",
    "{member} sent a request to join {circle}" : "{member} მომხმარებელმა გააგზვნა მოთხოვნა გაწევრიანდეს {circle} წრეში",
    "You are the new owner of {circle}" : "თქვენ ხართ {circle} წრის ახალი მფლობელი",
    "{member} is the new owner of {circle}" : "{member} ახლა {circle} წრის ახალი მფლობელია",
    "Shared to Circles" : "წრეებთან გაზიარებული",
    "Personal" : "პირადი",
    "System" : "სისტემა",
    "Visible" : "ჩანს",
    "Password protected" : "პაროლით დაცული",
    "Hidden" : "უჩინარი",
    "Local" : "ლოკალური",
    "Root" : "Root",
    "Federated" : "ფედერალური",
    "Contact" : "კონტაქტი",
    "Circle" : "წრე",
    "Member" : "წევრი",
    "Moderator" : "მოდერატორი",
    "Admin" : "ადმინისტრატორი",
    "Owner" : "მფლობელი",
    "%s shared »%s« with you." : "%s მომხმარებელმა თქვენთან გააზიარა »%s«.",
    "%s on %s" : "%s %s-ზე",
    "Password to access »%s«" : "პაროლი წვდომისთვის »%s«",
    "Click the button below to open it." : "გასახსნელად დააჭირეთ ქვემოთ მყოფ ღილაკს.",
    "Open »%s«" : "გახსენით »%s«",
    "This feature is not available for personal circles" : "ეს ფუნქცია პირადი წრეებისთვის არაა ძალაში მყოფი",
    "This member is not a moderator" : "ეს წევრი არაა მოდერატორი",
    "Insufficient privileges" : "პრივილეგიების უკმარისობა",
    "This member does not exist" : "ეს წევრი არ არსებობს",
    "Level cannot be changed for this type of member" : "დონე ამ ტიპის წევრზე ვერ შეიცვლება",
    "You are already a member of this circle" : "ამ წრის წევრი უკვე ხართ",
    "You have been blocked from this circle" : "ამ წრეში დაბლოკილი ხართ",
    "Accept" : "მიღება",
    "%s" : "%s",
    "No files in here" : "აქ ფაილები არაა",
    "No entries found in this folder" : "ამ დირექტორიაში შენატანები ვერ იქნა ნაპოვნი",
    "Name" : "სახელი",
    "Size" : "ზომა",
    "Modified" : "შეიცვალა"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/circles/l10n/ka_GE.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "თქვენ წაშალეთ {circle}",
    "{author} deleted {circle}" : "{author} მომხმარებელმა წაშალა {circle}",
    "You removed {member} from {circle}" : "თქვენ ამოშალეთ {member} {circle} წრიდან",
    "You joined {circle}" : "თქვენ შეუერთიდ წრეს {circle}",
    "{member} joined {circle}" : "{member} შეუერთდა წრეს {circle}",
    "You accepted the invitation to join {circle}" : "თქვენ მიიღეთ მოწვევა შეუერთდეთ {circle} წრეს",
    "{member} accepted the invitation to join {circle}" : "{member} მომხმარებელმა მიიღო მოწვევა შეუერთდეს {circle} წრეს",
    "You added {member} as member to {circle}" : "თქვენ მომხმარებელი {member} გააწევრიანეთ წრეში {circle}",
    "You have been added as member to {circle} by {author}" : "თქვენ {author} მომხმარებელმა გაგაწევრიანათ წრეში {circle}",
    "{member} has been added as member to {circle} by {author}" : "{member} წრეში {circle} გაწევრიანდა {author} მომხმარებლის მიერ",
    "You added {external} to {circle}" : "თქვენ დაამატეთ {external} წრეში {circle}",
    "{external} has been added to {circle} by {author}" : "{external} წრეში {circle} დაამატა მომხმარებელმა {author}",
    "You accepted {member}'s request to join {circle}" : "თქვენ მიიღეთ {member} წევრის მოთხოვნა {circle} წრეში გასაწევრიანებლად",
    "Your request to join {circle} has been accepted by {author}" : "თქვენი მოთხოვნა წრეში {circle} გაწევრიანებაზე მიიღო მომხმარებელმა {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} მომხმარებლისა მოთხოვნა გაწევრიანდეს {circle} წრეში მიღებულ იქნა {author} მომხმარებლის მიერ",
    "You left {circle}" : "თქვენ დატოვეთ {circle}",
    "{member} left {circle}" : "{member} მომხმარებელმა დატოვა {circle}",
    "You declined the invitation to join {circle}" : "თქვენ უარყავით მოწვევა გაწევრიანდეთ {circle} წრეში",
    "{member} declined an invitation to join {circle}" : "{member} მომხმარებელმა უარყო მოწვევა გაწევრიანდეს {circle} წრეში",
    "You cancelled your request to join {circle}" : "თქვენ გააუქმეთ მოთხოვნა გაწევრიანდეთ {circle} წრეში",
    "You have been removed from {circle} by {author}" : "თქვენ {author} მომხმარებელმა {circle} წრიდან ამოგშალათ",
    "{member} has been removed from {circle} by {author}" : "{member} მომხმარებელი {circle} წრიდან {author} მომხმარებელმა ამოშალა",
    "You removed {external} from {circle}" : "თქვენ {external} ამოშალეთ {circle} წრიდან",
    "{external} has been removed from {circle} by {author}" : "{author} მომხმარებელმა ამოშალა {external} წრიდან {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "თქვენ უარყავით {member} მომხმარებლის მოწვევა შეუერთდეთ {circle} წრეს",
    "Your invitation to join {circle} has been cancelled by {author}" : "მოწვევა რომ შეუერთდეთ {circle} უაყოფილ იქნა {author} მომხმარებლის მიერ",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} მომხმარებელმა უარყო {member} მომხმარებლის მოწვევა შეუერთდეს {circle} წრეს",
    "You dismissed {member}'s request to join {circle}" : "თქვენ უარყავით {member} მომხმარებლის მოთხოვნა {circle} წრეში გასაწევრიანებლად",
    "Your request to join {circle} has been dismissed by {author}" : "თქვენი მოთხოვნა შეუერთდეთ {circle} წრეს {author} მომხმარებლის მიერ უარყოფილ იქნა",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} მომხმარებლის მოთხოვნა შეუერთდეს {circle} წრეს უარყო {author} მომხმარებელმა",
    "You invited {member} to join {circle}" : "თქვენ მოიწვიეთ {member} შეუერთდეს {circle} წრეს",
    "You have been invited to join {circle} by {author}" : "თქვენ {author} მომხმარებელმა მოგიწვიათ შეუერთდეთ {circle} წრეს",
    "{member} has been invited to join {circle} by {author}" : "{author} მომხმარებელმა მოიწვია {member} მომხამრებელი შეუერთდეს {circle} წრეს",
    "You changed {member}'s level in {circle} to %1$s" : "თქვენ {member} მომხმარებლის დონე {circle} წრეში შეცვალეთ მნიშვნელობაზე %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} მომხმარებელმა თქვენი დონე {circle} წრეში შეცვალა მნიშვნელობაზე %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} მომხმარებელმა {member} მომხმარებლის დონე {circle} წრეში შეცვალა მნიშვნელობაზე %1$s",
    "You sent a request to join {circle}" : "თქვენ გაგზვნეთ მოთხოვნა გაწევრიანდეთ {circle} წრეში",
    "{member} sent a request to join {circle}" : "{member} მომხმარებელმა გააგზვნა მოთხოვნა გაწევრიანდეს {circle} წრეში",
    "You are the new owner of {circle}" : "თქვენ ხართ {circle} წრის ახალი მფლობელი",
    "{member} is the new owner of {circle}" : "{member} ახლა {circle} წრის ახალი მფლობელია",
    "Personal" : "პირადი",
    "System" : "სისტემა",
    "Visible" : "ჩანს",
    "Password protected" : "პაროლით დაცული",
    "Hidden" : "უჩინარი",
    "Local" : "ლოკალური",
    "Root" : "Root",
    "Federated" : "ფედერალური",
    "Contact" : "კონტაქტი",
    "Member" : "წევრი",
    "Moderator" : "მოდერატორი",
    "Admin" : "ადმინისტრატორი",
    "Owner" : "მფლობელი",
    "%s shared »%s« with you." : "%s მომხმარებელმა თქვენთან გააზიარა »%s«.",
    "%s on %s" : "%s %s-ზე",
    "Password to access »%s«" : "პაროლი წვდომისთვის »%s«",
    "Click the button below to open it." : "გასახსნელად დააჭირეთ ქვემოთ მყოფ ღილაკს.",
    "Open »%s«" : "გახსენით »%s«",
    "This feature is not available for personal circles" : "ეს ფუნქცია პირადი წრეებისთვის არაა ძალაში მყოფი",
    "This member is not a moderator" : "ეს წევრი არაა მოდერატორი",
    "Insufficient privileges" : "პრივილეგიების უკმარისობა",
    "This member does not exist" : "ეს წევრი არ არსებობს",
    "Level cannot be changed for this type of member" : "დონე ამ ტიპის წევრზე ვერ შეიცვლება",
    "You are already a member of this circle" : "ამ წრის წევრი უკვე ხართ",
    "You have been blocked from this circle" : "ამ წრეში დაბლოკილი ხართ",
    "Accept" : "მიღება",
    "%s" : "%s",
    "Try again" : "სცადეთ ახლიდან",
    "No files in here" : "აქ ფაილები არაა",
    "No entries found in this folder" : "ამ დირექტორიაში შენატანები ვერ იქნა ნაპოვნი",
    "Name" : "სახელი",
    "Size" : "ზომა",
    "Modified" : "შეიცვალა",
    "Shared to Circles" : "წრეებთან გაზიარებული"
},
"nplurals=2; plural=(n!=1);");
